=======================
PWBS Installation Guide
=======================

************************
Stable Release from PyPi
************************

* Install Python>3.6 from here `Python Downloads Website <https://www.python.org/downloads/>`_ (if it's not already installed)

* Install PWBS
    
    * Windows

        In CMD or other Command Line Interpreter execute: ``pip install pwbs``
    
    * Linux and others

        In Command Line execute: ``pip3 install pwbs``

**************************
Latest Development Release
**************************

* Install Python>3.6 from here `Python Downloads Website <https://www.python.org/downloads/>`_ (if it's not already installed)

* Install Git (if it's not already installed)

* In CMD or other Command Line Interpreter execute:

    * ``git clone https://gitlab.com/paip-web/pwbs.git``

    * ``cd pwbs``

    * ``pip install -e .`` or linux: ``pip3 install -e .``